@@ -177,7 +177,7 @@ test_that("Table functions", {
     "Cell Cycle freq", "Cell Cycle maxEAR"
   ) %in% names(statStuff)))
 
-  expect_equal(round(statStuff[["DNA Binding maxEAR"]][which(statStuff[["site"]] == "Raisin")], 4), 0.0278)
+  expect_equal(round(statStuff[["DNA Binding maxEAR"]][which(statStuff[["site"]] == "Raisin")], 4), 0.0301)
 
   expect_equal(round(statStuff[["DNA Binding freq"]][which(statStuff[["site"]] == "Raisin")], 4), 0)
 
@@ -185,7 +185,7 @@ test_that("Table functions", {
   expect_true(all(unique(groupStuff$site) %in% chem_site$`Short Name`))
   expect_true(all(c("site", "category", "Samples with hits", "Number of Samples") %in% names(groupStuff)))
   expect_equal(groupStuff[["Samples with hits"]][which(groupStuff[["site"]] == "Raisin" &
-    groupStuff[["category"]] == "Nuclear Receptor")], 27)
+    groupStuff[["category"]] == "Nuclear Receptor")], 29)
 
   expect_equal(groupStuff[["Number of Samples"]][which(groupStuff[["site"]] == "Raisin" &
     groupStuff[["category"]] == "DNA Binding")], 44)
@@ -197,11 +197,11 @@ test_that("Chem plotting functions", {
   graphData <- graph_chem_data(chemical_summary)
   expect_true(all(names(graphData) %in% c("site", "chnm", "Class", "meanEAR")))
   expect_equal(levels(graphData$Class)[1], "Herbicides")
-  expect_equal(levels(graphData$Class)[length(levels(graphData$Class))], "Fuels")
+  expect_equal(levels(graphData$Class)[length(levels(graphData$Class))], "Dyes/Pigments")
   expect_equal(signif(graphData[["meanEAR"]][graphData[["site"]] == "USGS-04024000" &
-    graphData[["chnm"]] == "Naphthalene"], 4), 0.002537)
+    graphData[["chnm"]] == "Naphthalene"], 4), 0.0004799)
   expect_equal(signif(graphData[["meanEAR"]][graphData[["site"]] == "USGS-04024000" &
-    graphData[["chnm"]] == "Cumene"], 4), 6.665e-06)
+    graphData[["chnm"]] == "Anthraquinone"], 4), 6.131e-05)
 })
 
 test_that("Map stuff functions", {
@@ -214,7 +214,7 @@ test_that("Map stuff functions", {
   expect_type(mapDataList, "list")
   expect_equal(length(mapDataList), 2)
   map_df <- mapDataList[["mapData"]]
-  expect_equal(signif(map_df[["meanMax"]][map_df[["Short Name"]] == "StLouis"], 4), 2.207)
+  expect_equal(signif(map_df[["meanMax"]][map_df[["Short Name"]] == "StLouis"], 4), 1.891)
 
   expect_equal(map_df[["count"]][map_df[["Short Name"]] == "StLouis"], 31)
   expect_equal(map_df[["sizes"]][map_df[["Short Name"]] == "StLouis"], 7.2)
@@ -232,17 +232,17 @@ test_that("Table endpoint hits", {
   bt <- endpoint_hits_DT(chemical_summary, category = "Biological")
   expect_type(bt, "list")
   expect_true(all(names(bt$x$data) %in% c(
-    "endPoint", "Nuclear Receptor", "CYP",
-    "Cell Cycle", "Steroid Hormone", "Esterase"
+    "endPoint", "Nuclear Receptor", "CYP", "Lyase",
+    "Steroid Hormone", "Esterase", "Metabolite"
   )))
   expect_true(all(class(bt) %in% c("datatables", "htmlwidget")))
 
   bt_df <- endpoint_hits(chemical_summary, category = "Biological")
   expect_true(all(names(bt_df) %in% c(
-    "endPoint", "Nuclear Receptor", "CYP",
-    "Cell Cycle", "Esterase", "Steroid Hormone"
+    "endPoint", "Nuclear Receptor", "CYP", "Lyase",
+    "Steroid Hormone", "Esterase", "Metabolite"
   )))
-  expect_equal(bt_df[["Nuclear Receptor"]][bt_df[["endPoint"]] == "OT_ER_ERaERb_1440"], 3)
+  expect_equal(bt_df[["Nuclear Receptor"]][bt_df[["endPoint"]] == "OT_ER_ERaERb_1440"], 1)
   expect_true(is.na(bt_df[["Esterase"]][bt_df[["endPoint"]] == "OT_ER_ERbERb_0480"]))
 
   expect_error(endpoint_hits_DT(chemical_summary, category = "Class"))
@@ -251,9 +251,9 @@ test_that("Table endpoint hits", {
   expect_type(ct, "list")
 
   expect_true(all(names(ct$x$data) %in% c(
-    "endPoint", "Antioxidants", "PAHs",
+    "endPoint", "Antioxidants", 
     "Detergent Metabolites", "Herbicides",
-    "Plasticizers"
+    "Antimicrobial Disinfectants"
   )))
 
   cht <- endpoint_hits_DT(chemical_summary, category = "Chemical")
@@ -262,7 +262,7 @@ test_that("Table endpoint hits", {
   expect_true(all(names(cht$x$data) %in% c(
     "endPoint", "Bisphenol A", "Metolachlor",
     "4-Nonylphenol, branched", "Pyrene",
-    "Phenanthrene", "Atrazine"
+    "Triclosan", "Atrazine"
   )))
 })
 
@@ -277,11 +277,12 @@ test_that("hits_by_groupings_DT", {
   bt_df <- hits_by_groupings(chemical_summary, category = "Chemical Class")
   expect_true(all(names(bt_df) %in% c(
     "Nuclear Receptor", "DNA Binding", "Cell Cycle", "Esterase",
-    "Steroid Hormone", "Channel 2", "CYP", "Transporter"
+    "Steroid Hormone", "Channel 2", "CYP", "Transporter", "Lyase",
+    "Metabolite"
   )))
 
   expect_true(all(c("Detergent Metabolites", "Antioxidants", "Herbicides") %in% rownames(bt_df)))
-  expect_equal(bt_df[["Nuclear Receptor"]], c(8, 10, 16, 2, rep(0, 10)))
+  expect_equal(bt_df[["Nuclear Receptor"]], c(8, 10, 16, rep(0, 9), NA))
 
   expect_error(hits_by_groupings_DT(chemical_summary, category = "Class"))
 
@@ -290,8 +291,8 @@ test_that("hits_by_groupings_DT", {
   expect_true(all(class(ct) %in% c("datatables", "htmlwidget")))
   expect_true(all(names(ct$x$data) %in% c(
     " ", "Nuclear Receptor", "DNA Binding", "Cell Cycle",
-    "Esterase", "CYP", "Steroid Hormone",
-    "Transporter", "Channel 2"
+    "Esterase", "CYP", "Steroid Hormone", "Lyase",
+    "Transporter", "Channel 2", "Metabolite"
   )))
 
 
@@ -301,7 +302,7 @@ test_that("hits_by_groupings_DT", {
   expect_true(all(names(cht$x$data) %in% c(
     " ", "Nuclear Receptor", "DNA Binding", "Cell Cycle",
     "CYP", "Esterase", "Steroid Hormone",
-    "Channel 2", "Transporter"
+    "Channel 2", "Transporter", "Lyase", "Metabolite"
   )))
 })
 
@@ -365,7 +366,7 @@ test_that("Calculating completness", {
   graphData2 <- tox_boxplot_data(chemical_summary, "Biological")
   complete_df_cat <- toxEval:::get_complete_set_category(chemical_summary, graphData2, tox_list$chem_site, category = "Biological")
 
-  expect_equal(nrow(complete_df_cat), 2394)
+  expect_equal(nrow(complete_df_cat), 2451)
 })
 
 test_that("Calculating concentrations", {
@@ -402,16 +403,13 @@ test_that("Testing levels", {
 
 
   expect_equal(chem_levels[1:5], c(
-    "Cumene",
-    "1-Methylnaphthalene",
-    "Anthraquinone",
-    "Tetrachloroethylene",
-    "Isophorone"
+    "Anthraquinone", "Tetrachloroethylene", "Isophorone",         
+    "1,4-Dichlorobenzene", "Bromoform"
   ))
   expect_equal(class_levels[1:5], c(
     "Herbicides", "Detergent Metabolites",
-    "Antioxidants", "PAHs",
-    "Antimicrobial Disinfectants"
+    "Antioxidants", "Antimicrobial Disinfectants",
+    "Fire Retardants"
   ))
 
   plot_eps <- plot_tox_endpoints(chemical_summary,
@@ -422,11 +420,11 @@ test_that("Testing levels", {
   expect_equal(
     tail(levels(plot_eps$data$endPoint), 5),
     c(
-      "LTEA_HepaRG_GCLC_dn",
-      "LTEA_HepaRG_NFE2L2_dn",
-      "LTEA_HepaRG_GSTA2_dn",
-      "TOX21_PPARg_BLA_Antagonist_ch2",
-      "TOX21_RT_HEPG2_FLO_00hr_ctrl_viability"
+      "LTEA_HepaRG_EZR",
+      "NVS_NR_mERa",
+      "LTEA_HepaRG_HSPA1A",
+      "LTEA_HepaRG_GSTM3",
+      "CLD_HMGCS2_48hr"
     )
   )
 
@@ -440,8 +438,9 @@ test_that("Testing levels", {
     levels(plot_stack$data$category),
     c(
       "Bisphenol A", "4-Nonylphenol, branched",
-      "Phenanthrene", "Atrazine",
-      "Pentachlorophenol", "Others (44)"
+      "Atrazine",
+      "Pentachlorophenol", "Metolachlor",
+      "Others (42)"
     )
   )
 
@@ -453,8 +452,11 @@ test_that("Testing levels", {
   expect_equal(
     tail(levels(plot_heat$data$chnm), 5),
     c(
-      "Bromacil", "Metolachlor", "Atrazine",
-      "Prometon", "Pentachlorophenol"
+      "Bromacil", 
+      "Metalaxyl",
+      "Metolachlor",
+      "Atrazine",
+      "Pentachlorophenol"
     )
   )
 })
